pub struct RxFilter<'a>(/* private fields */);Expand description
Producer of receiver filter update requests
Range removal requests may cover the entire ID range. The driver should efficiently process range requests with complexity bounded by the number of removed or remaining entries, not the range size.
Implementations